==> tomoscan_1.2.2.orig.tar.gz: tomoscan-1.2.2/tomoscan/esrf/identifier/__init__.py <==
# coding: utf-8
# /*##########################################################################
#
# Copyright (c) 2016-2022 European Synchrotron Radiation Facility
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# ###########################################################################*/

"""This module is dedicated to instances of :class:`BaseIdentifier` used at esrf"""

from .hdf5Identifier import HDF5TomoScanIdentifier  # noqa F401
from .edfidentifier import EDFTomoScanIdentifier  # noqa F401
from .jp2kidentifier import JP2KVolumeIdentifier  # noqa F401
from .tiffidentifier import TIFFVolumeIdentifier  # noqa F401
from .tiffidentifier import MultiTiffVolumeIdentifier  # noqa F401
from .rawidentifier import RawVolumeIdentifier  # noqa F401

==> tomoscan_2.0.5.orig.tar.gz: tomoscan-2.0.5/tomoscan/esrf/identifier/__init__.py <==
# coding: utf-8
# /*##########################################################################
#
# Copyright (c) 2016-2022 European Synchrotron Radiation Facility
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# ###########################################################################*/

"""This module is dedicated to instances of :class:`BaseIdentifier` used at esrf"""

from .edfidentifier import EDFTomoScanIdentifier  # noqa F401
from .hdf5Identifier import NXtomoScanIdentifier  # noqa F401
from .jp2kidentifier import JP2KVolumeIdentifier  # noqa F401
from .rawidentifier import RawVolumeIdentifier  # noqa F401
from .tiffidentifier import MultiTiffVolumeIdentifier  # noqa F401
from .tiffidentifier import TIFFVolumeIdentifier  # noqa F401
